import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface EfsFileSystemConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system.html#availability_zone_name EfsFileSystem#availability_zone_name}.
     *
     * @stability stable
     */
    readonly availabilityZoneName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system.html#creation_token EfsFileSystem#creation_token}.
     *
     * @stability stable
     */
    readonly creationToken?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system.html#encrypted EfsFileSystem#encrypted}.
     *
     * @stability stable
     */
    readonly encrypted?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system.html#kms_key_id EfsFileSystem#kms_key_id}.
     *
     * @stability stable
     */
    readonly kmsKeyId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system.html#performance_mode EfsFileSystem#performance_mode}.
     *
     * @stability stable
     */
    readonly performanceMode?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system.html#provisioned_throughput_in_mibps EfsFileSystem#provisioned_throughput_in_mibps}.
     *
     * @stability stable
     */
    readonly provisionedThroughputInMibps?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system.html#tags EfsFileSystem#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system.html#tags_all EfsFileSystem#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system.html#throughput_mode EfsFileSystem#throughput_mode}.
     *
     * @stability stable
     */
    readonly throughputMode?: string;
    /**
     * lifecycle_policy block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system.html#lifecycle_policy EfsFileSystem#lifecycle_policy}
     *
     * @stability stable
     */
    readonly lifecyclePolicy?: EfsFileSystemLifecyclePolicy[];
}
/**
 * @stability stable
 */
export declare class EfsFileSystemSizeInBytes extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get value(): number;
    /**
     * @stability stable
     */
    get valueInIa(): number;
    /**
     * @stability stable
     */
    get valueInStandard(): number;
}
/**
 * @stability stable
 */
export interface EfsFileSystemLifecyclePolicy {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system.html#transition_to_ia EfsFileSystem#transition_to_ia}.
     *
     * @stability stable
     */
    readonly transitionToIa: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system.html aws_efs_file_system}.
 *
 * @stability stable
 */
export declare class EfsFileSystem extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system.html aws_efs_file_system} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: EfsFileSystemConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get availabilityZoneId(): string;
    private _availabilityZoneName?;
    /**
     * @stability stable
     */
    get availabilityZoneName(): string;
    /**
     * @stability stable
     */
    set availabilityZoneName(value: string);
    /**
     * @stability stable
     */
    resetAvailabilityZoneName(): void;
    /**
     * @stability stable
     */
    get availabilityZoneNameInput(): string | undefined;
    private _creationToken?;
    /**
     * @stability stable
     */
    get creationToken(): string;
    /**
     * @stability stable
     */
    set creationToken(value: string);
    /**
     * @stability stable
     */
    resetCreationToken(): void;
    /**
     * @stability stable
     */
    get creationTokenInput(): string | undefined;
    /**
     * @stability stable
     */
    get dnsName(): string;
    private _encrypted?;
    /**
     * @stability stable
     */
    get encrypted(): boolean;
    /**
     * @stability stable
     */
    set encrypted(value: boolean);
    /**
     * @stability stable
     */
    resetEncrypted(): void;
    /**
     * @stability stable
     */
    get encryptedInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _kmsKeyId?;
    /**
     * @stability stable
     */
    get kmsKeyId(): string;
    /**
     * @stability stable
     */
    set kmsKeyId(value: string);
    /**
     * @stability stable
     */
    resetKmsKeyId(): void;
    /**
     * @stability stable
     */
    get kmsKeyIdInput(): string | undefined;
    /**
     * @stability stable
     */
    get numberOfMountTargets(): number;
    /**
     * @stability stable
     */
    get ownerId(): string;
    private _performanceMode?;
    /**
     * @stability stable
     */
    get performanceMode(): string;
    /**
     * @stability stable
     */
    set performanceMode(value: string);
    /**
     * @stability stable
     */
    resetPerformanceMode(): void;
    /**
     * @stability stable
     */
    get performanceModeInput(): string | undefined;
    private _provisionedThroughputInMibps?;
    /**
     * @stability stable
     */
    get provisionedThroughputInMibps(): number;
    /**
     * @stability stable
     */
    set provisionedThroughputInMibps(value: number);
    /**
     * @stability stable
     */
    resetProvisionedThroughputInMibps(): void;
    /**
     * @stability stable
     */
    get provisionedThroughputInMibpsInput(): number | undefined;
    /**
     * @stability stable
     */
    sizeInBytes(index: string): EfsFileSystemSizeInBytes;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    private _throughputMode?;
    /**
     * @stability stable
     */
    get throughputMode(): string;
    /**
     * @stability stable
     */
    set throughputMode(value: string);
    /**
     * @stability stable
     */
    resetThroughputMode(): void;
    /**
     * @stability stable
     */
    get throughputModeInput(): string | undefined;
    private _lifecyclePolicy?;
    /**
     * @stability stable
     */
    get lifecyclePolicy(): EfsFileSystemLifecyclePolicy[];
    /**
     * @stability stable
     */
    set lifecyclePolicy(value: EfsFileSystemLifecyclePolicy[]);
    /**
     * @stability stable
     */
    resetLifecyclePolicy(): void;
    /**
     * @stability stable
     */
    get lifecyclePolicyInput(): EfsFileSystemLifecyclePolicy[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
