import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ServiceDiscoveryServiceConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service.html#description ServiceDiscoveryService#description}.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service.html#name ServiceDiscoveryService#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service.html#namespace_id ServiceDiscoveryService#namespace_id}.
     *
     * @stability stable
     */
    readonly namespaceId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service.html#tags ServiceDiscoveryService#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service.html#tags_all ServiceDiscoveryService#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * dns_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service.html#dns_config ServiceDiscoveryService#dns_config}
     *
     * @stability stable
     */
    readonly dnsConfig?: ServiceDiscoveryServiceDnsConfig[];
    /**
     * health_check_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service.html#health_check_config ServiceDiscoveryService#health_check_config}
     *
     * @stability stable
     */
    readonly healthCheckConfig?: ServiceDiscoveryServiceHealthCheckConfig[];
    /**
     * health_check_custom_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service.html#health_check_custom_config ServiceDiscoveryService#health_check_custom_config}
     *
     * @stability stable
     */
    readonly healthCheckCustomConfig?: ServiceDiscoveryServiceHealthCheckCustomConfig[];
}
/**
 * @stability stable
 */
export interface ServiceDiscoveryServiceDnsConfigDnsRecords {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service.html#ttl ServiceDiscoveryService#ttl}.
     *
     * @stability stable
     */
    readonly ttl: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service.html#type ServiceDiscoveryService#type}.
     *
     * @stability stable
     */
    readonly type: string;
}
/**
 * @stability stable
 */
export interface ServiceDiscoveryServiceDnsConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service.html#namespace_id ServiceDiscoveryService#namespace_id}.
     *
     * @stability stable
     */
    readonly namespaceId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service.html#routing_policy ServiceDiscoveryService#routing_policy}.
     *
     * @stability stable
     */
    readonly routingPolicy?: string;
    /**
     * dns_records block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service.html#dns_records ServiceDiscoveryService#dns_records}
     *
     * @stability stable
     */
    readonly dnsRecords: ServiceDiscoveryServiceDnsConfigDnsRecords[];
}
/**
 * @stability stable
 */
export interface ServiceDiscoveryServiceHealthCheckConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service.html#failure_threshold ServiceDiscoveryService#failure_threshold}.
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service.html#resource_path ServiceDiscoveryService#resource_path}.
     *
     * @stability stable
     */
    readonly resourcePath?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service.html#type ServiceDiscoveryService#type}.
     *
     * @stability stable
     */
    readonly type?: string;
}
/**
 * @stability stable
 */
export interface ServiceDiscoveryServiceHealthCheckCustomConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service.html#failure_threshold ServiceDiscoveryService#failure_threshold}.
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service.html aws_service_discovery_service}.
 *
 * @stability stable
 */
export declare class ServiceDiscoveryService extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/service_discovery_service.html aws_service_discovery_service} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ServiceDiscoveryServiceConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _namespaceId?;
    /**
     * @stability stable
     */
    get namespaceId(): string;
    /**
     * @stability stable
     */
    set namespaceId(value: string);
    /**
     * @stability stable
     */
    resetNamespaceId(): void;
    /**
     * @stability stable
     */
    get namespaceIdInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    private _dnsConfig?;
    /**
     * @stability stable
     */
    get dnsConfig(): ServiceDiscoveryServiceDnsConfig[];
    /**
     * @stability stable
     */
    set dnsConfig(value: ServiceDiscoveryServiceDnsConfig[]);
    /**
     * @stability stable
     */
    resetDnsConfig(): void;
    /**
     * @stability stable
     */
    get dnsConfigInput(): ServiceDiscoveryServiceDnsConfig[] | undefined;
    private _healthCheckConfig?;
    /**
     * @stability stable
     */
    get healthCheckConfig(): ServiceDiscoveryServiceHealthCheckConfig[];
    /**
     * @stability stable
     */
    set healthCheckConfig(value: ServiceDiscoveryServiceHealthCheckConfig[]);
    /**
     * @stability stable
     */
    resetHealthCheckConfig(): void;
    /**
     * @stability stable
     */
    get healthCheckConfigInput(): ServiceDiscoveryServiceHealthCheckConfig[] | undefined;
    private _healthCheckCustomConfig?;
    /**
     * @stability stable
     */
    get healthCheckCustomConfig(): ServiceDiscoveryServiceHealthCheckCustomConfig[];
    /**
     * @stability stable
     */
    set healthCheckCustomConfig(value: ServiceDiscoveryServiceHealthCheckCustomConfig[]);
    /**
     * @stability stable
     */
    resetHealthCheckCustomConfig(): void;
    /**
     * @stability stable
     */
    get healthCheckCustomConfigInput(): ServiceDiscoveryServiceHealthCheckCustomConfig[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
