import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface SesEventDestinationConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination.html#configuration_set_name SesEventDestination#configuration_set_name}.
     *
     * @stability stable
     */
    readonly configurationSetName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination.html#enabled SesEventDestination#enabled}.
     *
     * @stability stable
     */
    readonly enabled?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination.html#matching_types SesEventDestination#matching_types}.
     *
     * @stability stable
     */
    readonly matchingTypes: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination.html#name SesEventDestination#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * cloudwatch_destination block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination.html#cloudwatch_destination SesEventDestination#cloudwatch_destination}
     *
     * @stability stable
     */
    readonly cloudwatchDestination?: SesEventDestinationCloudwatchDestination[];
    /**
     * kinesis_destination block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination.html#kinesis_destination SesEventDestination#kinesis_destination}
     *
     * @stability stable
     */
    readonly kinesisDestination?: SesEventDestinationKinesisDestination[];
    /**
     * sns_destination block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination.html#sns_destination SesEventDestination#sns_destination}
     *
     * @stability stable
     */
    readonly snsDestination?: SesEventDestinationSnsDestination[];
}
/**
 * @stability stable
 */
export interface SesEventDestinationCloudwatchDestination {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination.html#default_value SesEventDestination#default_value}.
     *
     * @stability stable
     */
    readonly defaultValue: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination.html#dimension_name SesEventDestination#dimension_name}.
     *
     * @stability stable
     */
    readonly dimensionName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination.html#value_source SesEventDestination#value_source}.
     *
     * @stability stable
     */
    readonly valueSource: string;
}
/**
 * @stability stable
 */
export interface SesEventDestinationKinesisDestination {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination.html#role_arn SesEventDestination#role_arn}.
     *
     * @stability stable
     */
    readonly roleArn: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination.html#stream_arn SesEventDestination#stream_arn}.
     *
     * @stability stable
     */
    readonly streamArn: string;
}
/**
 * @stability stable
 */
export interface SesEventDestinationSnsDestination {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination.html#topic_arn SesEventDestination#topic_arn}.
     *
     * @stability stable
     */
    readonly topicArn: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination.html aws_ses_event_destination}.
 *
 * @stability stable
 */
export declare class SesEventDestination extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination.html aws_ses_event_destination} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: SesEventDestinationConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _configurationSetName;
    /**
     * @stability stable
     */
    get configurationSetName(): string;
    /**
     * @stability stable
     */
    set configurationSetName(value: string);
    /**
     * @stability stable
     */
    get configurationSetNameInput(): string;
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean;
    /**
     * @stability stable
     */
    set enabled(value: boolean);
    /**
     * @stability stable
     */
    resetEnabled(): void;
    /**
     * @stability stable
     */
    get enabledInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _matchingTypes;
    /**
     * @stability stable
     */
    get matchingTypes(): string[];
    /**
     * @stability stable
     */
    set matchingTypes(value: string[]);
    /**
     * @stability stable
     */
    get matchingTypesInput(): string[];
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _cloudwatchDestination?;
    /**
     * @stability stable
     */
    get cloudwatchDestination(): SesEventDestinationCloudwatchDestination[];
    /**
     * @stability stable
     */
    set cloudwatchDestination(value: SesEventDestinationCloudwatchDestination[]);
    /**
     * @stability stable
     */
    resetCloudwatchDestination(): void;
    /**
     * @stability stable
     */
    get cloudwatchDestinationInput(): SesEventDestinationCloudwatchDestination[] | undefined;
    private _kinesisDestination?;
    /**
     * @stability stable
     */
    get kinesisDestination(): SesEventDestinationKinesisDestination[];
    /**
     * @stability stable
     */
    set kinesisDestination(value: SesEventDestinationKinesisDestination[]);
    /**
     * @stability stable
     */
    resetKinesisDestination(): void;
    /**
     * @stability stable
     */
    get kinesisDestinationInput(): SesEventDestinationKinesisDestination[] | undefined;
    private _snsDestination?;
    /**
     * @stability stable
     */
    get snsDestination(): SesEventDestinationSnsDestination[];
    /**
     * @stability stable
     */
    set snsDestination(value: SesEventDestinationSnsDestination[]);
    /**
     * @stability stable
     */
    resetSnsDestination(): void;
    /**
     * @stability stable
     */
    get snsDestinationInput(): SesEventDestinationSnsDestination[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
